from .types.v1 import list_metadata_pb2 as _list_metadata_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from ...validate.v1 import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateDatastoreRequest(_message.Message):
    __slots__ = ("name", "hostname", "port", "technology", "health_check_db_name", "db_discovery_job_wait_time", "db_discovery_native_role_id", "environment", "termination_protection")
    NAME_FIELD_NUMBER: _ClassVar[int]
    HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    TECHNOLOGY_FIELD_NUMBER: _ClassVar[int]
    HEALTH_CHECK_DB_NAME_FIELD_NUMBER: _ClassVar[int]
    DB_DISCOVERY_JOB_WAIT_TIME_FIELD_NUMBER: _ClassVar[int]
    DB_DISCOVERY_NATIVE_ROLE_ID_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    name: str
    hostname: str
    port: int
    technology: str
    health_check_db_name: str
    db_discovery_job_wait_time: str
    db_discovery_native_role_id: str
    environment: str
    termination_protection: bool
    def __init__(self, name: _Optional[str] = ..., hostname: _Optional[str] = ..., port: _Optional[int] = ..., technology: _Optional[str] = ..., health_check_db_name: _Optional[str] = ..., db_discovery_job_wait_time: _Optional[str] = ..., db_discovery_native_role_id: _Optional[str] = ..., environment: _Optional[str] = ..., termination_protection: bool = ...) -> None: ...

class CreateDatastoreResponse(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetDatastoreRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetDatastoreResponse(_message.Message):
    __slots__ = ("datastore",)
    DATASTORE_FIELD_NUMBER: _ClassVar[int]
    datastore: Datastore
    def __init__(self, datastore: _Optional[_Union[Datastore, _Mapping]] = ...) -> None: ...

class GetDatastoresRequest(_message.Message):
    __slots__ = ("limit", "cursor", "order", "filter", "search", "search_fields")
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    CURSOR_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELDS_FIELD_NUMBER: _ClassVar[int]
    limit: int
    cursor: str
    order: str
    filter: str
    search: str
    search_fields: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, limit: _Optional[int] = ..., cursor: _Optional[str] = ..., order: _Optional[str] = ..., filter: _Optional[str] = ..., search: _Optional[str] = ..., search_fields: _Optional[_Iterable[str]] = ...) -> None: ...

class GetDatastoresResponse(_message.Message):
    __slots__ = ("datastores", "list_metadata")
    DATASTORES_FIELD_NUMBER: _ClassVar[int]
    LIST_METADATA_FIELD_NUMBER: _ClassVar[int]
    datastores: _containers.RepeatedCompositeFieldContainer[Datastore]
    list_metadata: _list_metadata_pb2.ListMetadata
    def __init__(self, datastores: _Optional[_Iterable[_Union[Datastore, _Mapping]]] = ..., list_metadata: _Optional[_Union[_list_metadata_pb2.ListMetadata, _Mapping]] = ...) -> None: ...

class DeleteDatastoreRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteDatastoreResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UpdateDatastoreNameRequest(_message.Message):
    __slots__ = ("id", "name")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class UpdateDatastoreNameResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UpdateDbDiscoveryConfigRequest(_message.Message):
    __slots__ = ("id", "db_discovery_job_wait_time", "db_discovery_native_role_id")
    ID_FIELD_NUMBER: _ClassVar[int]
    DB_DISCOVERY_JOB_WAIT_TIME_FIELD_NUMBER: _ClassVar[int]
    DB_DISCOVERY_NATIVE_ROLE_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    db_discovery_job_wait_time: str
    db_discovery_native_role_id: str
    def __init__(self, id: _Optional[str] = ..., db_discovery_job_wait_time: _Optional[str] = ..., db_discovery_native_role_id: _Optional[str] = ...) -> None: ...

class UpdateDbDiscoveryConfigResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UpdateDataStoreHealthCheckDbNameRequest(_message.Message):
    __slots__ = ("id", "health_check_db_name")
    ID_FIELD_NUMBER: _ClassVar[int]
    HEALTH_CHECK_DB_NAME_FIELD_NUMBER: _ClassVar[int]
    id: str
    health_check_db_name: str
    def __init__(self, id: _Optional[str] = ..., health_check_db_name: _Optional[str] = ...) -> None: ...

class UpdateDataStoreHealthCheckDbNameResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UpdateDataStoreDefaultAccessBehaviorRequest(_message.Message):
    __slots__ = ("id", "default_access_behavior")
    ID_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_ACCESS_BEHAVIOR_FIELD_NUMBER: _ClassVar[int]
    id: str
    default_access_behavior: str
    def __init__(self, id: _Optional[str] = ..., default_access_behavior: _Optional[str] = ...) -> None: ...

class UpdateDataStoreDefaultAccessBehaviorResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SetTerminationProtectionRequest(_message.Message):
    __slots__ = ("id", "termination_protection")
    ID_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    id: str
    termination_protection: bool
    def __init__(self, id: _Optional[str] = ..., termination_protection: bool = ...) -> None: ...

class SetTerminationProtectionResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetLinkedSidecarsRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetLinkedSidecarsResponse(_message.Message):
    __slots__ = ("sidecars",)
    SIDECARS_FIELD_NUMBER: _ClassVar[int]
    sidecars: _containers.RepeatedCompositeFieldContainer[LinkedSidecar]
    def __init__(self, sidecars: _Optional[_Iterable[_Union[LinkedSidecar, _Mapping]]] = ...) -> None: ...

class LinkedSidecar(_message.Message):
    __slots__ = ("id", "name", "hostname", "link_id")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    LINK_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    hostname: str
    link_id: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., hostname: _Optional[str] = ..., link_id: _Optional[str] = ...) -> None: ...

class Datastore(_message.Message):
    __slots__ = ("id", "datastore_id", "name", "port", "hostname", "health_check_db_name", "technology", "created_at", "expire_at", "db_discovery_job_wait_time", "db_discovery_native_role_id", "default_access_behavior", "linked_logs", "environment", "termination_protection")
    ID_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    HEALTH_CHECK_DB_NAME_FIELD_NUMBER: _ClassVar[int]
    TECHNOLOGY_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    EXPIRE_AT_FIELD_NUMBER: _ClassVar[int]
    DB_DISCOVERY_JOB_WAIT_TIME_FIELD_NUMBER: _ClassVar[int]
    DB_DISCOVERY_NATIVE_ROLE_ID_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_ACCESS_BEHAVIOR_FIELD_NUMBER: _ClassVar[int]
    LINKED_LOGS_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    id: str
    datastore_id: str
    name: str
    port: int
    hostname: str
    health_check_db_name: str
    technology: str
    created_at: _timestamp_pb2.Timestamp
    expire_at: str
    db_discovery_job_wait_time: str
    db_discovery_native_role_id: str
    default_access_behavior: str
    linked_logs: _containers.RepeatedCompositeFieldContainer[IntegrationLog]
    environment: str
    termination_protection: bool
    def __init__(self, id: _Optional[str] = ..., datastore_id: _Optional[str] = ..., name: _Optional[str] = ..., port: _Optional[int] = ..., hostname: _Optional[str] = ..., health_check_db_name: _Optional[str] = ..., technology: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., expire_at: _Optional[str] = ..., db_discovery_job_wait_time: _Optional[str] = ..., db_discovery_native_role_id: _Optional[str] = ..., default_access_behavior: _Optional[str] = ..., linked_logs: _Optional[_Iterable[_Union[IntegrationLog, _Mapping]]] = ..., environment: _Optional[str] = ..., termination_protection: bool = ...) -> None: ...

class IntegrationLog(_message.Message):
    __slots__ = ("id", "name", "type", "created_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    type: str
    created_at: int
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., type: _Optional[str] = ..., created_at: _Optional[int] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SearchUser(_message.Message):
    __slots__ = ("id", "db_username", "type", "created_at", "updated_at", "first_name", "last_name", "email", "name", "expire_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    DB_USERNAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    EXPIRE_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    db_username: str
    type: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    first_name: str
    last_name: str
    email: str
    name: str
    expire_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., db_username: _Optional[str] = ..., type: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., first_name: _Optional[str] = ..., last_name: _Optional[str] = ..., email: _Optional[str] = ..., name: _Optional[str] = ..., expire_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class SearchGroup(_message.Message):
    __slots__ = ("id", "name", "description", "created_at", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class SearchPolicy(_message.Message):
    __slots__ = ("id", "name", "description", "created_at", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class SearchDatastore(_message.Message):
    __slots__ = ("id", "name", "hostname", "technology", "created_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    TECHNOLOGY_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    hostname: str
    technology: str
    created_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., hostname: _Optional[str] = ..., technology: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class SearchSidecar(_message.Message):
    __slots__ = ("id", "name", "hostname", "cloud_provider", "cloud_region", "deployment_type", "fail_open", "technology", "created_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    CLOUD_PROVIDER_FIELD_NUMBER: _ClassVar[int]
    CLOUD_REGION_FIELD_NUMBER: _ClassVar[int]
    DEPLOYMENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    FAIL_OPEN_FIELD_NUMBER: _ClassVar[int]
    TECHNOLOGY_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    hostname: str
    cloud_provider: str
    cloud_region: str
    deployment_type: str
    fail_open: bool
    technology: str
    created_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., hostname: _Optional[str] = ..., cloud_provider: _Optional[str] = ..., cloud_region: _Optional[str] = ..., deployment_type: _Optional[str] = ..., fail_open: bool = ..., technology: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class SearchInventory(_message.Message):
    __slots__ = ("id", "datastore_id", "path", "table_path", "name", "datastore_name", "table_physical_id", "table_attribute_number", "data_type", "data_labels", "data_label", "created_at", "updated_at", "validated", "tags", "encrypted")
    ID_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    TABLE_PATH_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_NAME_FIELD_NUMBER: _ClassVar[int]
    TABLE_PHYSICAL_ID_FIELD_NUMBER: _ClassVar[int]
    TABLE_ATTRIBUTE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    DATA_LABELS_FIELD_NUMBER: _ClassVar[int]
    DATA_LABEL_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    VALIDATED_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTED_FIELD_NUMBER: _ClassVar[int]
    id: str
    datastore_id: str
    path: str
    table_path: str
    name: str
    datastore_name: str
    table_physical_id: str
    table_attribute_number: int
    data_type: str
    data_labels: _containers.RepeatedScalarFieldContainer[str]
    data_label: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    validated: bool
    tags: _containers.RepeatedScalarFieldContainer[str]
    encrypted: bool
    def __init__(self, id: _Optional[str] = ..., datastore_id: _Optional[str] = ..., path: _Optional[str] = ..., table_path: _Optional[str] = ..., name: _Optional[str] = ..., datastore_name: _Optional[str] = ..., table_physical_id: _Optional[str] = ..., table_attribute_number: _Optional[int] = ..., data_type: _Optional[str] = ..., data_labels: _Optional[_Iterable[str]] = ..., data_label: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., validated: bool = ..., tags: _Optional[_Iterable[str]] = ..., encrypted: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/cord.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/cord.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x61\x64min/v1/cord.proto\x12\x08\x61\x64min.v1\"p\n\x19GetClientAuthTokenRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1b\n\tuser_name\x18\x02 \x01(\tR\x08userName\x12\x1d\n\nuser_email\x18\x03 \x01(\tR\tuserEmail\"2\n\x1aGetClientAuthTokenResponse\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\"\x1a\n\x04test\x12\x12\n\x04test\x18\x01 \x01(\tR\x04test2p\n\x0b\x43ordService\x12\x61\n\x12GetClientAuthToken\x12#.admin.v1.GetClientAuthTokenRequest\x1a$.admin.v1.GetClientAuthTokenResponse\"\x00\x42\x9f\x01\n\x0c\x63om.admin.v1B\tCordProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.cord_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\tCordProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETCLIENTAUTHTOKENREQUEST']._serialized_start=33
  _globals['_GETCLIENTAUTHTOKENREQUEST']._serialized_end=145
  _globals['_GETCLIENTAUTHTOKENRESPONSE']._serialized_start=147
  _globals['_GETCLIENTAUTHTOKENRESPONSE']._serialized_end=197
  _globals['_TEST']._serialized_start=199
  _globals['_TEST']._serialized_end=225
  _globals['_CORDSERVICE']._serialized_start=227
  _globals['_CORDSERVICE']._serialized_end=339
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/types/v1/key.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/types/v1/key.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61\x64min/v1/types/v1/key.proto\x12\x11\x61\x64min.v1.types.v1\"\xb6\x02\n\x03Key\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12!\n\x0c\x63loud_region\x18\x02 \x01(\tR\x0b\x63loudRegion\x12\x15\n\x06key_id\x18\x03 \x01(\tR\x05keyId\x12\x17\n\x07key_arn\x18\x04 \x01(\tR\x06keyArn\x12\x16\n\x06\x61\x63tive\x18\x05 \x01(\x08R\x06\x61\x63tive\x12\x1d\n\nmanaged_by\x18\x06 \x01(\tR\tmanagedBy\x12\x19\n\x08key_type\x18\x07 \x01(\tR\x07keyType\x12\x12\n\x04name\x18\x08 \x01(\tR\x04name\x12(\n\x10\x63loud_account_id\x18\t \x01(\tR\x0e\x63loudAccountId\x12\x1d\n\ncreated_at\x18\n \x01(\tR\tcreatedAt\x12\x1d\n\nupdated_at\x18\x0b \x01(\tR\tupdatedAtB\xd6\x01\n\x15\x63om.admin.v1.types.v1B\x08KeyProtoP\x01ZLgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.key_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\010KeyProtoP\001ZLgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_KEY']._serialized_start=51
  _globals['_KEY']._serialized_end=361
# @@protoc_insertion_point(module_scope)



from .types.v1 import list_metadata_pb2 as _list_metadata_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from ...validate.v1 import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListIntegrationMfasRequest(_message.Message):
    __slots__ = ("limit", "cursor", "order")
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    CURSOR_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    limit: int
    cursor: str
    order: str
    def __init__(self, limit: _Optional[int] = ..., cursor: _Optional[str] = ..., order: _Optional[str] = ...) -> None: ...

class ListIntegrationMfasResponse(_message.Message):
    __slots__ = ("integrations", "list_metadata")
    INTEGRATIONS_FIELD_NUMBER: _ClassVar[int]
    LIST_METADATA_FIELD_NUMBER: _ClassVar[int]
    integrations: _containers.RepeatedCompositeFieldContainer[IntegrationMfa]
    list_metadata: _list_metadata_pb2.ListMetadata
    def __init__(self, integrations: _Optional[_Iterable[_Union[IntegrationMfa, _Mapping]]] = ..., list_metadata: _Optional[_Union[_list_metadata_pb2.ListMetadata, _Mapping]] = ...) -> None: ...

class GetIntegrationMfaByIdRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetIntegrationMfaByIdResponse(_message.Message):
    __slots__ = ("integration",)
    INTEGRATION_FIELD_NUMBER: _ClassVar[int]
    integration: IntegrationMfa
    def __init__(self, integration: _Optional[_Union[IntegrationMfa, _Mapping]] = ...) -> None: ...

class CreateIntegrationMfaRequest(_message.Message):
    __slots__ = ("type", "duo_integration_key", "duo_secret_key", "duo_api_hostname", "termination_protection")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DUO_INTEGRATION_KEY_FIELD_NUMBER: _ClassVar[int]
    DUO_SECRET_KEY_FIELD_NUMBER: _ClassVar[int]
    DUO_API_HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    type: str
    duo_integration_key: str
    duo_secret_key: str
    duo_api_hostname: str
    termination_protection: bool
    def __init__(self, type: _Optional[str] = ..., duo_integration_key: _Optional[str] = ..., duo_secret_key: _Optional[str] = ..., duo_api_hostname: _Optional[str] = ..., termination_protection: bool = ...) -> None: ...

class CreateIntegrationMfaResponse(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteIntegrationMfaRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteIntegrationMfaResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UpdateIntegrationMfaRequest(_message.Message):
    __slots__ = ("id", "termination_protection")
    ID_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    id: str
    termination_protection: bool
    def __init__(self, id: _Optional[str] = ..., termination_protection: bool = ...) -> None: ...

class UpdateIntegrationMfaResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class IntegrationMfa(_message.Message):
    __slots__ = ("id", "created_at", "updated_at", "type", "duo_integration_key", "duo_secret_key", "duo_api_hostname", "termination_protection")
    ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DUO_INTEGRATION_KEY_FIELD_NUMBER: _ClassVar[int]
    DUO_SECRET_KEY_FIELD_NUMBER: _ClassVar[int]
    DUO_API_HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    id: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    type: str
    duo_integration_key: str
    duo_secret_key: str
    duo_api_hostname: str
    termination_protection: bool
    def __init__(self, id: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., type: _Optional[str] = ..., duo_integration_key: _Optional[str] = ..., duo_secret_key: _Optional[str] = ..., duo_api_hostname: _Optional[str] = ..., termination_protection: bool = ...) -> None: ...



import grpc


from .gen.admin.v1.cord_pb2 import (
	GetClientAuthTokenRequest,
	GetClientAuthTokenResponse,
	test,
)

from .gen.admin.v1.cord_pb2_grpc import CordServiceStub
class CordService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = CordServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def GetClientAuthToken(self, request: GetClientAuthTokenRequest) -> GetClientAuthTokenResponse:
		return self.stub.GetClientAuthToken(request, metadata=self.headers)




# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import integration_kms_pb2 as admin_dot_v1_dot_integration__kms__pb2


class KmsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateKeyRegistration = channel.unary_unary(
                '/admin.v1.KmsService/CreateKeyRegistration',
                request_serializer=admin_dot_v1_dot_integration__kms__pb2.CreateKeyRegistrationRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__kms__pb2.CreateKeyRegistrationResponse.FromString,
                _registered_method=True)
        self.GetKeys = channel.unary_unary(
                '/admin.v1.KmsService/GetKeys',
                request_serializer=admin_dot_v1_dot_integration__kms__pb2.GetKeysRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__kms__pb2.GetKeysResponse.FromString,
                _registered_method=True)
        self.GetKey = channel.unary_unary(
                '/admin.v1.KmsService/GetKey',
                request_serializer=admin_dot_v1_dot_integration__kms__pb2.GetKeyRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__kms__pb2.GetKeyResponse.FromString,
                _registered_method=True)
        self.DeactivateFieldEncryptionKey = channel.unary_unary(
                '/admin.v1.KmsService/DeactivateFieldEncryptionKey',
                request_serializer=admin_dot_v1_dot_integration__kms__pb2.DeactivateFieldEncryptionKeyRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__kms__pb2.DeactivateFieldEncryptionKeyResponse.FromString,
                _registered_method=True)


class KmsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateKeyRegistration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetKeys(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeactivateFieldEncryptionKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_KmsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateKeyRegistration': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateKeyRegistration,
                    request_deserializer=admin_dot_v1_dot_integration__kms__pb2.CreateKeyRegistrationRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__kms__pb2.CreateKeyRegistrationResponse.SerializeToString,
            ),
            'GetKeys': grpc.unary_unary_rpc_method_handler(
                    servicer.GetKeys,
                    request_deserializer=admin_dot_v1_dot_integration__kms__pb2.GetKeysRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__kms__pb2.GetKeysResponse.SerializeToString,
            ),
            'GetKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GetKey,
                    request_deserializer=admin_dot_v1_dot_integration__kms__pb2.GetKeyRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__kms__pb2.GetKeyResponse.SerializeToString,
            ),
            'DeactivateFieldEncryptionKey': grpc.unary_unary_rpc_method_handler(
                    servicer.DeactivateFieldEncryptionKey,
                    request_deserializer=admin_dot_v1_dot_integration__kms__pb2.DeactivateFieldEncryptionKeyRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__kms__pb2.DeactivateFieldEncryptionKeyResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.KmsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('admin.v1.KmsService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class KmsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateKeyRegistration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.KmsService/CreateKeyRegistration',
            admin_dot_v1_dot_integration__kms__pb2.CreateKeyRegistrationRequest.SerializeToString,
            admin_dot_v1_dot_integration__kms__pb2.CreateKeyRegistrationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetKeys(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.KmsService/GetKeys',
            admin_dot_v1_dot_integration__kms__pb2.GetKeysRequest.SerializeToString,
            admin_dot_v1_dot_integration__kms__pb2.GetKeysResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.KmsService/GetKey',
            admin_dot_v1_dot_integration__kms__pb2.GetKeyRequest.SerializeToString,
            admin_dot_v1_dot_integration__kms__pb2.GetKeyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeactivateFieldEncryptionKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.KmsService/DeactivateFieldEncryptionKey',
            admin_dot_v1_dot_integration__kms__pb2.DeactivateFieldEncryptionKeyRequest.SerializeToString,
            admin_dot_v1_dot_integration__kms__pb2.DeactivateFieldEncryptionKeyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



import grpc


from .gen.admin.v1.sidecar_pb2 import (
	ListSidecarsRequest,
	ListSidecarsResponse,
	GetSidecarVersionsRequest,
	GetSidecarVersionsResponse,
	CreateSidecarRequest,
	CreateSidecarResponse,
	GetSidecarByIdRequest,
	GetSidecarByIdResponse,
	GetSidecarTlsCertificateByIdRequest,
	GetSidecarTlsCertificateByIdResponse,
	UpdateSidecarNameRequest,
	UpdateSidecarNameResponse,
	UpdateSidecarVersionRequest,
	UpdateSidecarVersionResponse,
	UpdateSidecarFormalHostnameRequest,
	UpdateSidecarFormalHostnameResponse,
	UpdateSidecarKmsDecryptPolicyRequest,
	UpdateSidecarKmsDecryptPolicyResponse,
	DeleteSidecarRequest,
	DeleteSidecarResponse,
	CreateSidecarDatastoreLinkRequest,
	CreateSidecarDatastoreLinkResponse,
	DeleteSidecarDatastoreLinkRequest,
	DeleteSidecarDatastoreLinkResponse,
	GetLinkByIdRequest,
	GetLinkByIdResponse,
	GetLinksBySidecarIdRequest,
	GetLinksBySidecarIdResponse,
	GetLinksByDatastoreIdRequest,
	GetLinksByDatastoreIdResponse,
	UpdateTerminationProtectionRequest,
	UpdateTerminationProtectionResponse,
	UpdateSidecarDatastoreLinkRequest,
	UpdateSidecarDatastoreLinkResponse,
)

from .gen.admin.v1.sidecar_pb2_grpc import SidecarServiceStub
class SidecarService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = SidecarServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def ListSidecars(self, request: ListSidecarsRequest) -> ListSidecarsResponse:
		return self.stub.ListSidecars(request, metadata=self.headers)

	def GetSidecarVersions(self, request: GetSidecarVersionsRequest) -> GetSidecarVersionsResponse:
		return self.stub.GetSidecarVersions(request, metadata=self.headers)

	def CreateSidecar(self, request: CreateSidecarRequest) -> CreateSidecarResponse:
		return self.stub.CreateSidecar(request, metadata=self.headers)

	def GetSidecarById(self, request: GetSidecarByIdRequest) -> GetSidecarByIdResponse:
		return self.stub.GetSidecarById(request, metadata=self.headers)

	def GetSidecarTlsCertificateById(self, request: GetSidecarTlsCertificateByIdRequest) -> GetSidecarTlsCertificateByIdResponse:
		return self.stub.GetSidecarTlsCertificateById(request, metadata=self.headers)

	def UpdateSidecarName(self, request: UpdateSidecarNameRequest) -> UpdateSidecarNameResponse:
		return self.stub.UpdateSidecarName(request, metadata=self.headers)

	def UpdateSidecarVersion(self, request: UpdateSidecarVersionRequest) -> UpdateSidecarVersionResponse:
		return self.stub.UpdateSidecarVersion(request, metadata=self.headers)

	def UpdateSidecarFormalHostname(self, request: UpdateSidecarFormalHostnameRequest) -> UpdateSidecarFormalHostnameResponse:
		return self.stub.UpdateSidecarFormalHostname(request, metadata=self.headers)

	def UpdateSidecarKmsDecryptPolicy(self, request: UpdateSidecarKmsDecryptPolicyRequest) -> UpdateSidecarKmsDecryptPolicyResponse:
		return self.stub.UpdateSidecarKmsDecryptPolicy(request, metadata=self.headers)

	def UpdateTerminationProtection(self, request: UpdateTerminationProtectionRequest) -> UpdateTerminationProtectionResponse:
		return self.stub.UpdateTerminationProtection(request, metadata=self.headers)

	def DeleteSidecar(self, request: DeleteSidecarRequest) -> DeleteSidecarResponse:
		return self.stub.DeleteSidecar(request, metadata=self.headers)

	def CreateSidecarDatastoreLink(self, request: CreateSidecarDatastoreLinkRequest) -> CreateSidecarDatastoreLinkResponse:
		return self.stub.CreateSidecarDatastoreLink(request, metadata=self.headers)

	def GetLinkById(self, request: GetLinkByIdRequest) -> GetLinkByIdResponse:
		return self.stub.GetLinkById(request, metadata=self.headers)

	def GetLinksBySidecarId(self, request: GetLinksBySidecarIdRequest) -> GetLinksBySidecarIdResponse:
		return self.stub.GetLinksBySidecarId(request, metadata=self.headers)

	def GetLinksByDatastoreId(self, request: GetLinksByDatastoreIdRequest) -> GetLinksByDatastoreIdResponse:
		return self.stub.GetLinksByDatastoreId(request, metadata=self.headers)

	def UpdateSidecarDatastoreLink(self, request: UpdateSidecarDatastoreLinkRequest) -> UpdateSidecarDatastoreLinkResponse:
		return self.stub.UpdateSidecarDatastoreLink(request, metadata=self.headers)

	def DeleteSidecarDatastoreLink(self, request: DeleteSidecarDatastoreLinkRequest) -> DeleteSidecarDatastoreLinkResponse:
		return self.stub.DeleteSidecarDatastoreLink(request, metadata=self.headers)




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/sidecar.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/sidecar.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import list_metadata_pb2 as admin_dot_v1_dot_types_dot_v1_dot_list__metadata__pb2
from .types.v1 import sidecar_pb2 as admin_dot_v1_dot_types_dot_v1_dot_sidecar__pb2
from .types.v1 import sidecar_link_pb2 as admin_dot_v1_dot_types_dot_v1_dot_sidecar__link__pb2
from ...validate.v1 import validate_pb2 as validate_dot_v1_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61\x64min/v1/sidecar.proto\x12\x08\x61\x64min.v1\x1a%admin/v1/types/v1/list_metadata.proto\x1a\x1f\x61\x64min/v1/types/v1/sidecar.proto\x1a$admin/v1/types/v1/sidecar_link.proto\x1a\x1avalidate/v1/validate.proto\"\xf5\x01\n\x13ListSidecarsRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\x12\x14\n\x05order\x18\x03 \x01(\tR\x05order\x12\x16\n\x06search\x18\x04 \x01(\tR\x06search\x12\x81\x01\n\rsearch_fields\x18\x05 \x03(\tB\\\xfa\x42Y\x92\x01V\"TrRR\x04nameR\ntechnologyR\x0e\x63loud_providerR\x0c\x63loud_regionR\x0f\x66ormal_hostnameR\x0f\x64\x65ployment_typeR\x0csearchFields\"\x94\x01\n\x14ListSidecarsResponse\x12\x36\n\x08sidecars\x18\x01 \x03(\x0b\x32\x1a.admin.v1.types.v1.SidecarR\x08sidecars\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata\";\n\x19GetSidecarVersionsRequest\x12\x1e\n\ntechnology\x18\x01 \x01(\tR\ntechnology\"8\n\x1aGetSidecarVersionsResponse\x12\x1a\n\x08versions\x18\x01 \x03(\tR\x08versions\"\xb1\x04\n\x14\x43reateSidecarRequest\x12,\n\x04name\x18\x01 \x01(\tB\x18\xfa\x42\x15r\x13\x10\x03\x18?2\r^[0-9a-z\\-]+$R\x04name\x12\x93\x01\n\ntechnology\x18\x02 \x01(\tBs\xfa\x42prnR\x08postgresR\x08redshiftR\x05mysqlR\x07mariadbR\tsnowflakeR\x02s3R\x08\x64ynamodbR\x07mongodbR\ndocumentdbR\x08\x62igqueryR\x04httpR\x03sshR\x05multiR\ntechnology\x12\'\n\x0f\x64\x65ployment_type\x18\x03 \x01(\tR\x0e\x64\x65ploymentType\x12!\n\x0c\x64\x61taplane_id\x18\x04 \x01(\tR\x0b\x64\x61taplaneId\x12!\n\x0c\x64\x61tastore_id\x18\x05 \x01(\tR\x0b\x64\x61tastoreId\x12\x1b\n\tfail_open\x18\x06 \x01(\x08R\x08\x66\x61ilOpen\x12,\n\x12global_kms_decrypt\x18\x07 \x01(\x08R\x10globalKmsDecrypt\x12\'\n\x0f\x66ormal_hostname\x18\x08 \x01(\tR\x0e\x66ormalHostname\x12\x18\n\x07version\x18\t \x01(\tR\x07version\x12!\n\x0cnetwork_type\x18\n \x01(\tR\x0bnetworkType\x12\x35\n\x16termination_protection\x18\x0b \x01(\x08R\x15terminationProtection\"\'\n\x15\x43reateSidecarResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\'\n\x15GetSidecarByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"N\n\x16GetSidecarByIdResponse\x12\x34\n\x07sidecar\x18\x01 \x01(\x0b\x32\x1a.admin.v1.types.v1.SidecarR\x07sidecar\"5\n#GetSidecarTlsCertificateByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\">\n$GetSidecarTlsCertificateByIdResponse\x12\x16\n\x06secret\x18\x01 \x01(\tR\x06secret\">\n\x18UpdateSidecarNameRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"\x1b\n\x19UpdateSidecarNameResponse\"G\n\x1bUpdateSidecarVersionRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x18\n\x07version\x18\x02 \x01(\tR\x07version\"\x1e\n\x1cUpdateSidecarVersionResponse\"P\n\"UpdateSidecarFormalHostnameRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1a\n\x08hostname\x18\x02 \x01(\tR\x08hostname\"%\n#UpdateSidecarFormalHostnameResponse\"P\n$UpdateSidecarKmsDecryptPolicyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x18\n\x07\x65nabled\x18\x02 \x01(\x08R\x07\x65nabled\"\'\n%UpdateSidecarKmsDecryptPolicyResponse\"&\n\x14\x44\x65leteSidecarRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x17\n\x15\x44\x65leteSidecarResponse\"\xb0\x01\n!CreateSidecarDatastoreLinkRequest\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tR\x0b\x64\x61tastoreId\x12\x1d\n\nsidecar_id\x18\x02 \x01(\tR\tsidecarId\x12\x12\n\x04port\x18\x03 \x01(\x05R\x04port\x12\x35\n\x16termination_protection\x18\x04 \x01(\x08R\x15terminationProtection\"=\n\"CreateSidecarDatastoreLinkResponse\x12\x17\n\x07link_id\x18\x01 \x01(\tR\x06linkId\"<\n!DeleteSidecarDatastoreLinkRequest\x12\x17\n\x07link_id\x18\x01 \x01(\tR\x06linkId\"$\n\"DeleteSidecarDatastoreLinkResponse\"$\n\x12GetLinkByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"I\n\x13GetLinkByIdResponse\x12\x32\n\x04link\x18\x01 \x01(\x0b\x32\x1e.admin.v1.types.v1.SidecarLinkR\x04link\";\n\x1aGetLinksBySidecarIdRequest\x12\x1d\n\nsidecar_id\x18\x01 \x01(\tR\tsidecarId\"S\n\x1bGetLinksBySidecarIdResponse\x12\x34\n\x05links\x18\x01 \x03(\x0b\x32\x1e.admin.v1.types.v1.SidecarLinkR\x05links\"A\n\x1cGetLinksByDatastoreIdRequest\x12!\n\x0c\x64\x61tastore_id\x18\x02 \x01(\tR\x0b\x64\x61tastoreId\"U\n\x1dGetLinksByDatastoreIdResponse\x12\x34\n\x05links\x18\x01 \x03(\x0b\x32\x1e.admin.v1.types.v1.SidecarLinkR\x05links\"N\n\"UpdateTerminationProtectionRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x18\n\x07\x65nabled\x18\x02 \x01(\x08R\x07\x65nabled\"%\n#UpdateTerminationProtectionResponse\"\x8a\x01\n!UpdateSidecarDatastoreLinkRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12:\n\x16termination_protection\x18\x02 \x01(\x08H\x00R\x15terminationProtection\x88\x01\x01\x42\x19\n\x17_termination_protection\"$\n\"UpdateSidecarDatastoreLinkResponse2\x9f\x0e\n\x0eSidecarService\x12O\n\x0cListSidecars\x12\x1d.admin.v1.ListSidecarsRequest\x1a\x1e.admin.v1.ListSidecarsResponse\"\x00\x12\x61\n\x12GetSidecarVersions\x12#.admin.v1.GetSidecarVersionsRequest\x1a$.admin.v1.GetSidecarVersionsResponse\"\x00\x12R\n\rCreateSidecar\x12\x1e.admin.v1.CreateSidecarRequest\x1a\x1f.admin.v1.CreateSidecarResponse\"\x00\x12U\n\x0eGetSidecarById\x12\x1f.admin.v1.GetSidecarByIdRequest\x1a .admin.v1.GetSidecarByIdResponse\"\x00\x12\x7f\n\x1cGetSidecarTlsCertificateById\x12-.admin.v1.GetSidecarTlsCertificateByIdRequest\x1a..admin.v1.GetSidecarTlsCertificateByIdResponse\"\x00\x12^\n\x11UpdateSidecarName\x12\".admin.v1.UpdateSidecarNameRequest\x1a#.admin.v1.UpdateSidecarNameResponse\"\x00\x12g\n\x14UpdateSidecarVersion\x12%.admin.v1.UpdateSidecarVersionRequest\x1a&.admin.v1.UpdateSidecarVersionResponse\"\x00\x12|\n\x1bUpdateSidecarFormalHostname\x12,.admin.v1.UpdateSidecarFormalHostnameRequest\x1a-.admin.v1.UpdateSidecarFormalHostnameResponse\"\x00\x12\x82\x01\n\x1dUpdateSidecarKmsDecryptPolicy\x12..admin.v1.UpdateSidecarKmsDecryptPolicyRequest\x1a/.admin.v1.UpdateSidecarKmsDecryptPolicyResponse\"\x00\x12|\n\x1bUpdateTerminationProtection\x12,.admin.v1.UpdateTerminationProtectionRequest\x1a-.admin.v1.UpdateTerminationProtectionResponse\"\x00\x12R\n\rDeleteSidecar\x12\x1e.admin.v1.DeleteSidecarRequest\x1a\x1f.admin.v1.DeleteSidecarResponse\"\x00\x12y\n\x1a\x43reateSidecarDatastoreLink\x12+.admin.v1.CreateSidecarDatastoreLinkRequest\x1a,.admin.v1.CreateSidecarDatastoreLinkResponse\"\x00\x12L\n\x0bGetLinkById\x12\x1c.admin.v1.GetLinkByIdRequest\x1a\x1d.admin.v1.GetLinkByIdResponse\"\x00\x12\x64\n\x13GetLinksBySidecarId\x12$.admin.v1.GetLinksBySidecarIdRequest\x1a%.admin.v1.GetLinksBySidecarIdResponse\"\x00\x12j\n\x15GetLinksByDatastoreId\x12&.admin.v1.GetLinksByDatastoreIdRequest\x1a\'.admin.v1.GetLinksByDatastoreIdResponse\"\x00\x12y\n\x1aUpdateSidecarDatastoreLink\x12+.admin.v1.UpdateSidecarDatastoreLinkRequest\x1a,.admin.v1.UpdateSidecarDatastoreLinkResponse\"\x00\x12y\n\x1a\x44\x65leteSidecarDatastoreLink\x12+.admin.v1.DeleteSidecarDatastoreLinkRequest\x1a,.admin.v1.DeleteSidecarDatastoreLinkResponse\"\x00\x42\xa2\x01\n\x0c\x63om.admin.v1B\x0cSidecarProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.sidecar_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\014SidecarProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_LISTSIDECARSREQUEST'].fields_by_name['search_fields']._loaded_options = None
  _globals['_LISTSIDECARSREQUEST'].fields_by_name['search_fields']._serialized_options = b'\372BY\222\001V\"TrRR\004nameR\ntechnologyR\016cloud_providerR\014cloud_regionR\017formal_hostnameR\017deployment_type'
  _globals['_CREATESIDECARREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATESIDECARREQUEST'].fields_by_name['name']._serialized_options = b'\372B\025r\023\020\003\030?2\r^[0-9a-z\\-]+$'
  _globals['_CREATESIDECARREQUEST'].fields_by_name['technology']._loaded_options = None
  _globals['_CREATESIDECARREQUEST'].fields_by_name['technology']._serialized_options = b'\372BprnR\010postgresR\010redshiftR\005mysqlR\007mariadbR\tsnowflakeR\002s3R\010dynamodbR\007mongodbR\ndocumentdbR\010bigqueryR\004httpR\003sshR\005multi'
  _globals['_LISTSIDECARSREQUEST']._serialized_start=175
  _globals['_LISTSIDECARSREQUEST']._serialized_end=420
  _globals['_LISTSIDECARSRESPONSE']._serialized_start=423
  _globals['_LISTSIDECARSRESPONSE']._serialized_end=571
  _globals['_GETSIDECARVERSIONSREQUEST']._serialized_start=573
  _globals['_GETSIDECARVERSIONSREQUEST']._serialized_end=632
  _globals['_GETSIDECARVERSIONSRESPONSE']._serialized_start=634
  _globals['_GETSIDECARVERSIONSRESPONSE']._serialized_end=690
  _globals['_CREATESIDECARREQUEST']._serialized_start=693
  _globals['_CREATESIDECARREQUEST']._serialized_end=1254
  _globals['_CREATESIDECARRESPONSE']._serialized_start=1256
  _globals['_CREATESIDECARRESPONSE']._serialized_end=1295
  _globals['_GETSIDECARBYIDREQUEST']._serialized_start=1297
  _globals['_GETSIDECARBYIDREQUEST']._serialized_end=1336
  _globals['_GETSIDECARBYIDRESPONSE']._serialized_start=1338
  _globals['_GETSIDECARBYIDRESPONSE']._serialized_end=1416
  _globals['_GETSIDECARTLSCERTIFICATEBYIDREQUEST']._serialized_start=1418
  _globals['_GETSIDECARTLSCERTIFICATEBYIDREQUEST']._serialized_end=1471
  _globals['_GETSIDECARTLSCERTIFICATEBYIDRESPONSE']._serialized_start=1473
  _globals['_GETSIDECARTLSCERTIFICATEBYIDRESPONSE']._serialized_end=1535
  _globals['_UPDATESIDECARNAMEREQUEST']._serialized_start=1537
  _globals['_UPDATESIDECARNAMEREQUEST']._serialized_end=1599
  _globals['_UPDATESIDECARNAMERESPONSE']._serialized_start=1601
  _globals['_UPDATESIDECARNAMERESPONSE']._serialized_end=1628
  _globals['_UPDATESIDECARVERSIONREQUEST']._serialized_start=1630
  _globals['_UPDATESIDECARVERSIONREQUEST']._serialized_end=1701
  _globals['_UPDATESIDECARVERSIONRESPONSE']._serialized_start=1703
  _globals['_UPDATESIDECARVERSIONRESPONSE']._serialized_end=1733
  _globals['_UPDATESIDECARFORMALHOSTNAMEREQUEST']._serialized_start=1735
  _globals['_UPDATESIDECARFORMALHOSTNAMEREQUEST']._serialized_end=1815
  _globals['_UPDATESIDECARFORMALHOSTNAMERESPONSE']._serialized_start=1817
  _globals['_UPDATESIDECARFORMALHOSTNAMERESPONSE']._serialized_end=1854
  _globals['_UPDATESIDECARKMSDECRYPTPOLICYREQUEST']._serialized_start=1856
  _globals['_UPDATESIDECARKMSDECRYPTPOLICYREQUEST']._serialized_end=1936
  _globals['_UPDATESIDECARKMSDECRYPTPOLICYRESPONSE']._serialized_start=1938
  _globals['_UPDATESIDECARKMSDECRYPTPOLICYRESPONSE']._serialized_end=1977
  _globals['_DELETESIDECARREQUEST']._serialized_start=1979
  _globals['_DELETESIDECARREQUEST']._serialized_end=2017
  _globals['_DELETESIDECARRESPONSE']._serialized_start=2019
  _globals['_DELETESIDECARRESPONSE']._serialized_end=2042
  _globals['_CREATESIDECARDATASTORELINKREQUEST']._serialized_start=2045
  _globals['_CREATESIDECARDATASTORELINKREQUEST']._serialized_end=2221
  _globals['_CREATESIDECARDATASTORELINKRESPONSE']._serialized_start=2223
  _globals['_CREATESIDECARDATASTORELINKRESPONSE']._serialized_end=2284
  _globals['_DELETESIDECARDATASTORELINKREQUEST']._serialized_start=2286
  _globals['_DELETESIDECARDATASTORELINKREQUEST']._serialized_end=2346
  _globals['_DELETESIDECARDATASTORELINKRESPONSE']._serialized_start=2348
  _globals['_DELETESIDECARDATASTORELINKRESPONSE']._serialized_end=2384
  _globals['_GETLINKBYIDREQUEST']._serialized_start=2386
  _globals['_GETLINKBYIDREQUEST']._serialized_end=2422
  _globals['_GETLINKBYIDRESPONSE']._serialized_start=2424
  _globals['_GETLINKBYIDRESPONSE']._serialized_end=2497
  _globals['_GETLINKSBYSIDECARIDREQUEST']._serialized_start=2499
  _globals['_GETLINKSBYSIDECARIDREQUEST']._serialized_end=2558
  _globals['_GETLINKSBYSIDECARIDRESPONSE']._serialized_start=2560
  _globals['_GETLINKSBYSIDECARIDRESPONSE']._serialized_end=2643
  _globals['_GETLINKSBYDATASTOREIDREQUEST']._serialized_start=2645
  _globals['_GETLINKSBYDATASTOREIDREQUEST']._serialized_end=2710
  _globals['_GETLINKSBYDATASTOREIDRESPONSE']._serialized_start=2712
  _globals['_GETLINKSBYDATASTOREIDRESPONSE']._serialized_end=2797
  _globals['_UPDATETERMINATIONPROTECTIONREQUEST']._serialized_start=2799
  _globals['_UPDATETERMINATIONPROTECTIONREQUEST']._serialized_end=2877
  _globals['_UPDATETERMINATIONPROTECTIONRESPONSE']._serialized_start=2879
  _globals['_UPDATETERMINATIONPROTECTIONRESPONSE']._serialized_end=2916
  _globals['_UPDATESIDECARDATASTORELINKREQUEST']._serialized_start=2919
  _globals['_UPDATESIDECARDATASTORELINKREQUEST']._serialized_end=3057
  _globals['_UPDATESIDECARDATASTORELINKRESPONSE']._serialized_start=3059
  _globals['_UPDATESIDECARDATASTORELINKRESPONSE']._serialized_end=3095
  _globals['_SIDECARSERVICE']._serialized_start=3098
  _globals['_SIDECARSERVICE']._serialized_end=4921
# @@protoc_insertion_point(module_scope)



from .types.v1 import incident_account_pb2 as _incident_account_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DeleteIncidentAccountByIdRequest(_message.Message):
    __slots__ = ["account_id"]
    ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    account_id: str
    def __init__(self, account_id: _Optional[str] = ...) -> None: ...

class DeleteIncidentAccountByIdResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ConnectIncidentAccountRequest(_message.Message):
    __slots__ = ["name", "type", "logo", "api_key"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    LOGO_FIELD_NUMBER: _ClassVar[int]
    API_KEY_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: str
    logo: str
    api_key: str
    def __init__(self, name: _Optional[str] = ..., type: _Optional[str] = ..., logo: _Optional[str] = ..., api_key: _Optional[str] = ...) -> None: ...

class ConnectIncidentAccountResponse(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetIncidentAccountsRequest(_message.Message):
    __slots__ = ["limit", "cursor", "go_back"]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    CURSOR_FIELD_NUMBER: _ClassVar[int]
    GO_BACK_FIELD_NUMBER: _ClassVar[int]
    limit: str
    cursor: str
    go_back: bool
    def __init__(self, limit: _Optional[str] = ..., cursor: _Optional[str] = ..., go_back: bool = ...) -> None: ...

class GetIncidentAccountsResponse(_message.Message):
    __slots__ = ["accounts", "last_evaluated_key", "has_more"]
    ACCOUNTS_FIELD_NUMBER: _ClassVar[int]
    LAST_EVALUATED_KEY_FIELD_NUMBER: _ClassVar[int]
    HAS_MORE_FIELD_NUMBER: _ClassVar[int]
    accounts: _containers.RepeatedCompositeFieldContainer[_incident_account_pb2.IncidentAccount]
    last_evaluated_key: str
    has_more: bool
    def __init__(self, accounts: _Optional[_Iterable[_Union[_incident_account_pb2.IncidentAccount, _Mapping]]] = ..., last_evaluated_key: _Optional[str] = ..., has_more: bool = ...) -> None: ...

class GetIncidentAccountByIdRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetIncidentAccountByIdResponse(_message.Message):
    __slots__ = ["account"]
    ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    account: _incident_account_pb2.IncidentAccount
    def __init__(self, account: _Optional[_Union[_incident_account_pb2.IncidentAccount, _Mapping]] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from .....validate.v1 import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Policy(_message.Message):
    __slots__ = ("id", "name", "description", "code", "ast", "notification", "owners", "source_type", "created_at", "updated_at", "active", "termination_protection")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    AST_FIELD_NUMBER: _ClassVar[int]
    NOTIFICATION_FIELD_NUMBER: _ClassVar[int]
    OWNERS_FIELD_NUMBER: _ClassVar[int]
    SOURCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    code: str
    ast: str
    notification: str
    owners: _containers.RepeatedScalarFieldContainer[str]
    source_type: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    active: bool
    termination_protection: bool
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., code: _Optional[str] = ..., ast: _Optional[str] = ..., notification: _Optional[str] = ..., owners: _Optional[_Iterable[str]] = ..., source_type: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., active: bool = ..., termination_protection: bool = ...) -> None: ...

class PolicyV2(_message.Message):
    __slots__ = ("id", "name", "description", "code", "ast", "notification", "owners", "source_type", "created_at", "updated_at", "active", "status", "termination_protection")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    AST_FIELD_NUMBER: _ClassVar[int]
    NOTIFICATION_FIELD_NUMBER: _ClassVar[int]
    OWNERS_FIELD_NUMBER: _ClassVar[int]
    SOURCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    code: str
    ast: str
    notification: str
    owners: _containers.RepeatedScalarFieldContainer[str]
    source_type: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    active: bool
    status: str
    termination_protection: bool
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., code: _Optional[str] = ..., ast: _Optional[str] = ..., notification: _Optional[str] = ..., owners: _Optional[_Iterable[str]] = ..., source_type: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., active: bool = ..., status: _Optional[str] = ..., termination_protection: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/types/v1/flat_dataplane.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/types/v1/flat_dataplane.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&admin/v1/types/v1/flat_dataplane.proto\x12\x11\x61\x64min.v1.types.v1\"\xdb\x10\n\rFlatDataplane\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x16\n\x06region\x18\x03 \x01(\tR\x06region\x12&\n\x0f\x63ustomer_vpc_id\x18\x04 \x01(\tR\rcustomerVpcId\x12\x37\n\x18original_customer_vpc_id\x18\x05 \x01(\tR\x15originalCustomerVpcId\x12(\n\x10\x63loud_account_id\x18\x06 \x01(\tR\x0e\x63loudAccountId\x12+\n\x11\x61vailability_zone\x18\x07 \x01(\x05R\x10\x61vailabilityZone\x12\x39\n\x19vpc_peering_connection_id\x18\x08 \x01(\tR\x16vpcPeeringConnectionId\x12G\n!formal_r53_private_hosted_zone_id\x18\t \x01(\tR\x1c\x66ormalR53PrivateHostedZoneId\x12\x41\n\x1e\x66ormal_vpc_flow_logs_group_arn\x18\n \x01(\tR\x19\x66ormalVpcFlowLogsGroupArn\x12\x41\n\x1e\x66ormal_vpc_flow_log_group_name\x18\x0b \x01(\tR\x19\x66ormalVpcFlowLogGroupName\x12\x46\n!formal_vpc_flow_logs_iam_role_arn\x18\x0c \x01(\tR\x1b\x66ormalVpcFlowLogsIamRoleArn\x12J\n#formal_vpc_flow_logs_iam_policy_arn\x18\r \x01(\tR\x1d\x66ormalVpcFlowLogsIamPolicyArn\x12)\n\x11\x66ormal_vpc_igw_id\x18\x0e \x01(\tR\x0e\x66ormalVpcIgwId\x12&\n\x0f\x65gress_only_igw\x18\x0f \x01(\tR\regressOnlyIgw\x12\x84\x01\n\x1e\x66ormal_vpc_private_subnets_ids\x18\x10 \x03(\x0b\x32@.admin.v1.types.v1.FlatDataplane.FormalVpcPrivateSubnetsIdsEntryR\x1a\x66ormalVpcPrivateSubnetsIds\x12\x81\x01\n\x1d\x66ormal_vpc_public_subnets_ids\x18\x11 \x03(\x0b\x32?.admin.v1.types.v1.FlatDataplane.FormalVpcPublicSubnetsIdsEntryR\x19\x66ormalVpcPublicSubnetsIds\x12\x32\n\x15\x66ormal_public_subnets\x18\x12 \x03(\tR\x13\x66ormalPublicSubnets\x12\x34\n\x16\x66ormal_private_subnets\x18\x13 \x03(\tR\x14\x66ormalPrivateSubnets\x12\x45\n formal_vpc_public_route_table_id\x18\x14 \x01(\tR\x1b\x66ormalVpcPublicRouteTableId\x12\x39\n\x19\x63ustomer_vpc_route_tables\x18\x15 \x03(\tR\x16\x63ustomerVpcRouteTables\x12\x65\n\x13\x66ormal_vpc_natg_ids\x18\x16 \x03(\x0b\x32\x36.admin.v1.types.v1.FlatDataplane.FormalVpcNatgIdsEntryR\x10\x66ormalVpcNatgIds\x12h\n\x14\x66ormal_vpc_natg_eips\x18\x17 \x03(\x0b\x32\x37.admin.v1.types.v1.FlatDataplane.FormalVpcNatgEipsEntryR\x11\x66ormalVpcNatgEips\x12\x42\n\x1e\x66ormal_vpc_public_route_tables\x18\x18 \x01(\tR\x1a\x66ormalVpcPublicRouteTables\x12O\n%formal_vpc_private_route_table_routes\x18\x19 \x03(\tR formalVpcPrivateRouteTableRoutes\x12\"\n\rformal_vpc_id\x18\x1a \x01(\tR\x0b\x66ormalVpcId\x12\x31\n\x15\x66ormal_vpc_cidr_block\x18\x1b \x01(\tR\x12\x66ormalVpcCidrBlock\x12(\n\x10\x65\x63s_cluster_name\x18\x1c \x01(\tR\x0e\x65\x63sClusterName\x12&\n\x0f\x65\x63s_cluster_arn\x18\x1d \x01(\tR\recsClusterArn\x12\x16\n\x06status\x18\x1e \x01(\tR\x06status\x12\x1f\n\x0bvpc_peering\x18\x1f \x01(\x08R\nvpcPeering\x1aM\n\x1f\x46ormalVpcPrivateSubnetsIdsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1aL\n\x1e\x46ormalVpcPublicSubnetsIdsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x43\n\x15\x46ormalVpcNatgIdsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x44\n\x16\x46ormalVpcNatgEipsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x8d\x02\n\x1d\x44\x61taplaneTransitGatewayRoutes\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12!\n\x0c\x64\x61taplane_id\x18\x02 \x01(\tR\x0b\x64\x61taplaneId\x12\x34\n\x16\x64\x65stination_cidr_block\x18\x03 \x01(\tR\x14\x64\x65stinationCidrBlock\x12,\n\x12transit_gateway_id\x18\x04 \x01(\tR\x10transitGatewayId\x12\x39\n\x19vpc_peering_connection_id\x18\x05 \x01(\tR\x16vpcPeeringConnectionId\x12\x1a\n\x08\x64\x65ployed\x18\x06 \x01(\x08R\x08\x64\x65ployed\"\xf2\x05\n\x10\x43loudIntegration\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\"\n\raws_formal_id\x18\x02 \x01(\tR\x0b\x61wsFormalId\x12,\n\x12\x63loud_account_name\x18\x03 \x01(\tR\x10\x63loudAccountName\x12\x10\n\x03url\x18\x04 \x01(\tR\x03url\x12%\n\x0e\x63loud_provider\x18\x05 \x01(\tR\rcloudProvider\x12$\n\x0e\x61ws_account_id\x18\x06 \x01(\tR\x0c\x61wsAccountId\x12-\n\x13\x61ws_formal_iam_role\x18\x07 \x01(\tR\x10\x61wsFormalIamRole\x12\x35\n\x17\x61ws_formal_handshake_id\x18\x08 \x01(\tR\x14\x61wsFormalHandshakeId\x12$\n\x0egcp_project_id\x18\t \x01(\tR\x0cgcpProjectId\x12#\n\rtemplate_body\x18\n \x01(\tR\x0ctemplateBody\x12/\n\x14\x61ws_formal_user_name\x18\x0b \x01(\tR\x11\x61wsFormalUserName\x12\x35\n\x17\x61ws_formal_pingback_arn\x18\x0c \x01(\tR\x14\x61wsFormalPingbackArn\x12\x31\n\x15\x61ws_formal_stack_name\x18\r \x01(\tR\x12\x61wsFormalStackName\x12(\n\x10\x61ws_cloud_region\x18\x0e \x01(\tR\x0e\x61wsCloudRegion\x12N\n%aws_formal_r53_private_hosted_zone_id\x18\x0f \x01(\tR\x1f\x61wsFormalR53PrivateHostedZoneId\x12\x38\n\x06stacks\x18\x10 \x03(\x0b\x32 .admin.v1.types.v1.FlatDataplaneR\x06stacks\x12\x1d\n\ncreated_at\x18\x11 \x01(\tR\tcreatedAtB\xe0\x01\n\x15\x63om.admin.v1.types.v1B\x12\x46latDataplaneProtoP\x01ZLgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.flat_dataplane_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\022FlatDataplaneProtoP\001ZLgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_FLATDATAPLANE_FORMALVPCPRIVATESUBNETSIDSENTRY']._loaded_options = None
  _globals['_FLATDATAPLANE_FORMALVPCPRIVATESUBNETSIDSENTRY']._serialized_options = b'8\001'
  _globals['_FLATDATAPLANE_FORMALVPCPUBLICSUBNETSIDSENTRY']._loaded_options = None
  _globals['_FLATDATAPLANE_FORMALVPCPUBLICSUBNETSIDSENTRY']._serialized_options = b'8\001'
  _globals['_FLATDATAPLANE_FORMALVPCNATGIDSENTRY']._loaded_options = None
  _globals['_FLATDATAPLANE_FORMALVPCNATGIDSENTRY']._serialized_options = b'8\001'
  _globals['_FLATDATAPLANE_FORMALVPCNATGEIPSENTRY']._loaded_options = None
  _globals['_FLATDATAPLANE_FORMALVPCNATGEIPSENTRY']._serialized_options = b'8\001'
  _globals['_FLATDATAPLANE']._serialized_start=62
  _globals['_FLATDATAPLANE']._serialized_end=2201
  _globals['_FLATDATAPLANE_FORMALVPCPRIVATESUBNETSIDSENTRY']._serialized_start=1907
  _globals['_FLATDATAPLANE_FORMALVPCPRIVATESUBNETSIDSENTRY']._serialized_end=1984
  _globals['_FLATDATAPLANE_FORMALVPCPUBLICSUBNETSIDSENTRY']._serialized_start=1986
  _globals['_FLATDATAPLANE_FORMALVPCPUBLICSUBNETSIDSENTRY']._serialized_end=2062
  _globals['_FLATDATAPLANE_FORMALVPCNATGIDSENTRY']._serialized_start=2064
  _globals['_FLATDATAPLANE_FORMALVPCNATGIDSENTRY']._serialized_end=2131
  _globals['_FLATDATAPLANE_FORMALVPCNATGEIPSENTRY']._serialized_start=2133
  _globals['_FLATDATAPLANE_FORMALVPCNATGEIPSENTRY']._serialized_end=2201
  _globals['_DATAPLANETRANSITGATEWAYROUTES']._serialized_start=2204
  _globals['_DATAPLANETRANSITGATEWAYROUTES']._serialized_end=2473
  _globals['_CLOUDINTEGRATION']._serialized_start=2476
  _globals['_CLOUDINTEGRATION']._serialized_end=3230
# @@protoc_insertion_point(module_scope)



import grpc


from .gen.admin.v1.registry_pb2 import (
	OnlineInstance,
	OnlineSidecar,
	GetOnlineInstancesByOrgIdRequest,
	GetOnlineInstancesByOrgIdResponse,
	GetOnlineInstancesBySidecarIdRequest,
	GetOnlineInstancesBySidecarIdResponse,
)

from .gen.admin.v1.registry_pb2_grpc import RegistryServiceStub
class RegistryService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = RegistryServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def GetOnlineInstancesByOrgId(self, request: GetOnlineInstancesByOrgIdRequest) -> GetOnlineInstancesByOrgIdResponse:
		return self.stub.GetOnlineInstancesByOrgId(request, metadata=self.headers)

	def GetOnlineInstancesBySidecarId(self, request: GetOnlineInstancesBySidecarIdRequest) -> GetOnlineInstancesBySidecarIdResponse:
		return self.stub.GetOnlineInstancesBySidecarId(request, metadata=self.headers)




import grpc


from .gen.admin.v1.datastore_pb2 import (
	CreateDatastoreRequest,
	CreateDatastoreResponse,
	GetDatastoreRequest,
	GetDatastoreResponse,
	GetDatastoresRequest,
	GetDatastoresResponse,
	DeleteDatastoreRequest,
	DeleteDatastoreResponse,
	UpdateDatastoreNameRequest,
	UpdateDatastoreNameResponse,
	UpdateDbDiscoveryConfigRequest,
	UpdateDbDiscoveryConfigResponse,
	UpdateDataStoreHealthCheckDbNameRequest,
	UpdateDataStoreHealthCheckDbNameResponse,
	UpdateDataStoreDefaultAccessBehaviorRequest,
	UpdateDataStoreDefaultAccessBehaviorResponse,
	SetTerminationProtectionRequest,
	SetTerminationProtectionResponse,
	GetLinkedSidecarsRequest,
	GetLinkedSidecarsResponse,
	LinkedSidecar,
	Datastore,
	IntegrationLog,
)

from .gen.admin.v1.datastore_pb2_grpc import DataStoreServiceStub
class DataStoreService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = DataStoreServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def CreateDatastore(self, request: CreateDatastoreRequest) -> CreateDatastoreResponse:
		return self.stub.CreateDatastore(request, metadata=self.headers)

	def GetDatastore(self, request: GetDatastoreRequest) -> GetDatastoreResponse:
		return self.stub.GetDatastore(request, metadata=self.headers)

	def GetDatastores(self, request: GetDatastoresRequest) -> GetDatastoresResponse:
		return self.stub.GetDatastores(request, metadata=self.headers)

	def GetLinkedSidecars(self, request: GetLinkedSidecarsRequest) -> GetLinkedSidecarsResponse:
		return self.stub.GetLinkedSidecars(request, metadata=self.headers)

	def DeleteDatastore(self, request: DeleteDatastoreRequest) -> DeleteDatastoreResponse:
		return self.stub.DeleteDatastore(request, metadata=self.headers)

	def UpdateDatastoreName(self, request: UpdateDatastoreNameRequest) -> UpdateDatastoreNameResponse:
		return self.stub.UpdateDatastoreName(request, metadata=self.headers)

	def UpdateDbDiscoveryConfig(self, request: UpdateDbDiscoveryConfigRequest) -> UpdateDbDiscoveryConfigResponse:
		return self.stub.UpdateDbDiscoveryConfig(request, metadata=self.headers)

	def UpdateDataStoreHealthCheckDbName(self, request: UpdateDataStoreHealthCheckDbNameRequest) -> UpdateDataStoreHealthCheckDbNameResponse:
		return self.stub.UpdateDataStoreHealthCheckDbName(request, metadata=self.headers)

	def UpdateDataStoreDefaultAccessBehavior(self, request: UpdateDataStoreDefaultAccessBehaviorRequest) -> UpdateDataStoreDefaultAccessBehaviorResponse:
		return self.stub.UpdateDataStoreDefaultAccessBehavior(request, metadata=self.headers)

	def SetTerminationProtection(self, request: SetTerminationProtectionRequest) -> SetTerminationProtectionResponse:
		return self.stub.SetTerminationProtection(request, metadata=self.headers)




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/outputs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61\x64min/v1/outputs.proto\x12\x08\x61\x64min.v1\x1a\x1fgoogle/protobuf/timestamp.proto\",\n\x11GetOutputsRequest\x12\x17\n\x07item_id\x18\x01 \x01(\tR\x06itemId\"F\n\x12GetOutputsResponse\x12\x30\n\x07records\x18\x01 \x03(\x0b\x32\x16.admin.v1.OutputRecordR\x07records\"\xa9\x01\n\x0cOutputRecord\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07item_id\x18\x02 \x01(\tR\x06itemId\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\x12\x39\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x1b\n\tlog_level\x18\x05 \x01(\tR\x08logLevel2[\n\x0eOutputsService\x12I\n\nGetOutputs\x12\x1b.admin.v1.GetOutputsRequest\x1a\x1c.admin.v1.GetOutputsResponse\"\x00\x42\xa7\x01\n\x0c\x63om.admin.v1B\x0cOutputsProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.outputs_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\014com.admin.v1B\014OutputsProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETOUTPUTSREQUEST']._serialized_start=69
  _globals['_GETOUTPUTSREQUEST']._serialized_end=113
  _globals['_GETOUTPUTSRESPONSE']._serialized_start=115
  _globals['_GETOUTPUTSRESPONSE']._serialized_end=185
  _globals['_OUTPUTRECORD']._serialized_start=188
  _globals['_OUTPUTRECORD']._serialized_end=357
  _globals['_OUTPUTSSERVICE']._serialized_start=359
  _globals['_OUTPUTSSERVICE']._serialized_end=450
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/identities.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/identities.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import external_id_pb2 as admin_dot_v1_dot_types_dot_v1_dot_external__id__pb2
from .types.v1 import group_pb2 as admin_dot_v1_dot_types_dot_v1_dot_group__pb2
from .types.v1 import list_metadata_pb2 as admin_dot_v1_dot_types_dot_v1_dot_list__metadata__pb2
from .types.v1 import user_pb2 as admin_dot_v1_dot_types_dot_v1_dot_user__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ...validate.v1 import validate_pb2 as validate_dot_v1_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x61\x64min/v1/identities.proto\x12\x08\x61\x64min.v1\x1a#admin/v1/types/v1/external_id.proto\x1a\x1d\x61\x64min/v1/types/v1/group.proto\x1a%admin/v1/types/v1/list_metadata.proto\x1a\x1c\x61\x64min/v1/types/v1/user.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1avalidate/v1/validate.proto\"\xb3\x01\n\x11ListGroupsRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\x12\x14\n\x05order\x18\x03 \x01(\tR\x05order\x12\x16\n\x06search\x18\x04 \x01(\tR\x06search\x12\x42\n\rsearch_fields\x18\x05 \x03(\tB\x1d\xfa\x42\x1a\x92\x01\x17\"\x15r\x13R\x04nameR\x0b\x64\x65scriptionR\x0csearchFields\"\x81\x01\n\x12\x43reateGroupRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x35\n\x16termination_protection\x18\x03 \x01(\x08R\x15terminationProtection\"%\n\x13GetGroupByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"$\n\x12\x44\x65leteGroupRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\xb1\x01\n\x12UpdateGroupRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12:\n\x16termination_protection\x18\x04 \x01(\x08H\x00R\x15terminationProtection\x88\x01\x01\x42\x19\n\x17_termination_protection\"D\n\x17LinkUsersToGroupRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x19\n\x08user_ids\x18\x02 \x03(\tR\x07userIds\"F\n\x19LinkUsersToGroupV2Request\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x19\n\x08user_ids\x18\x02 \x03(\tR\x07userIds\"H\n\x1bUnlinkUsersFromGroupRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x19\n\x08user_ids\x18\x02 \x03(\tR\x07userIds\"E\n\x13\x43reateGroupResponse\x12.\n\x05group\x18\x01 \x01(\x0b\x32\x18.admin.v1.types.v1.GroupR\x05group\"F\n\x14GetGroupByIdResponse\x12.\n\x05group\x18\x01 \x01(\x0b\x32\x18.admin.v1.types.v1.GroupR\x05group\"E\n\x13\x44\x65leteGroupResponse\x12.\n\x05group\x18\x01 \x01(\x0b\x32\x18.admin.v1.types.v1.GroupR\x05group\"E\n\x13UpdateGroupResponse\x12.\n\x05group\x18\x01 \x01(\x0b\x32\x18.admin.v1.types.v1.GroupR\x05group\"\x8c\x01\n\x12ListGroupsResponse\x12\x30\n\x06groups\x18\x01 \x03(\x0b\x32\x18.admin.v1.types.v1.GroupR\x06groups\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata\"P\n\x18LinkUsersToGroupResponse\x12\x19\n\x08user_ids\x18\x01 \x03(\tR\x07userIds\x12\x19\n\x08group_id\x18\x02 \x01(\tR\x07groupId\"R\n\x1aLinkUsersToGroupV2Response\x12\x19\n\x08user_ids\x18\x01 \x03(\tR\x07userIds\x12\x19\n\x08group_id\x18\x02 \x01(\tR\x07groupId\"T\n\x1cUnlinkUsersFromGroupResponse\x12\x19\n\x08user_ids\x18\x01 \x03(\tR\x07userIds\x12\x19\n\x08group_id\x18\x02 \x01(\tR\x07groupId\"M\n\x15UserLinkGroupResponse\x12\x19\n\x08user_ids\x18\x01 \x03(\tR\x07userIds\x12\x19\n\x08group_id\x18\x02 \x01(\tR\x07groupId\"\xb2\x01\n\x10ListUsersRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\x12\x14\n\x05order\x18\x03 \x01(\tR\x05order\x12\x16\n\x06search\x18\x04 \x01(\tR\x06search\x12\x42\n\rsearch_fields\x18\x05 \x03(\tB\x1d\xfa\x42\x1a\x92\x01\x17\"\x15r\x13R\x0b\x64\x62_usernameR\x04typeR\x0csearchFields\"\x88\x01\n\x11ListUsersResponse\x12-\n\x05users\x18\x01 \x03(\x0b\x32\x17.admin.v1.types.v1.UserR\x05users\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata\"\xef\x02\n\x11\x43reateUserRequest\x12\x1d\n\nfirst_name\x18\x01 \x01(\tR\tfirstName\x12\x1b\n\tlast_name\x18\x02 \x01(\tR\x08lastName\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12\x19\n\x08\x61pp_type\x18\x04 \x01(\tR\x07\x61ppType\x12\x15\n\x06\x61pp_id\x18\x05 \x01(\tR\x05\x61ppId\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x14\n\x05\x65mail\x18\x07 \x01(\tR\x05\x65mail\x12\x14\n\x05\x61\x64min\x18\x08 \x01(\x08R\x05\x61\x64min\x12\x10\n\x03idp\x18\t \x01(\tR\x03idp\x12\x16\n\x06status\x18\n \x01(\tR\x06status\x12\x37\n\texpire_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08\x65xpireAt\x12\x35\n\x16termination_protection\x18\x0c \x01(\x08R\x15terminationProtection\"^\n\x12\x43reateUserResponse\x12+\n\x04user\x18\x01 \x01(\x0b\x32\x17.admin.v1.types.v1.UserR\x04user\x12\x1b\n\ttenant_id\x18\x02 \x01(\tR\x08tenantId\"\xf1\x02\n\x13\x43reateUserV2Request\x12\x1d\n\nfirst_name\x18\x01 \x01(\tR\tfirstName\x12\x1b\n\tlast_name\x18\x02 \x01(\tR\x08lastName\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12\x19\n\x08\x61pp_type\x18\x04 \x01(\tR\x07\x61ppType\x12\x15\n\x06\x61pp_id\x18\x05 \x01(\tR\x05\x61ppId\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x14\n\x05\x65mail\x18\x07 \x01(\tR\x05\x65mail\x12\x14\n\x05\x61\x64min\x18\x08 \x01(\x08R\x05\x61\x64min\x12\x10\n\x03idp\x18\t \x01(\tR\x03idp\x12\x16\n\x06status\x18\n \x01(\tR\x06status\x12\x37\n\texpire_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08\x65xpireAt\x12\x35\n\x16termination_protection\x18\x0c \x01(\x08R\x15terminationProtection\"&\n\x14\x43reateUserV2Response\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"$\n\x12GetUserByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"B\n\x13GetUserByIdResponse\x12+\n\x04user\x18\x01 \x01(\x0b\x32\x17.admin.v1.types.v1.UserR\x04user\"#\n\x11\x44\x65leteUserRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x14\n\x12\x44\x65leteUserResponse\"\xe0\x01\n\x11UpdateUserRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1d\n\nfirst_name\x18\x03 \x01(\tR\tfirstName\x12\x1b\n\tlast_name\x18\x04 \x01(\tR\x08lastName\x12\x14\n\x05\x65mail\x18\x05 \x01(\tR\x05\x65mail\x12:\n\x16termination_protection\x18\x0c \x01(\x08H\x00R\x15terminationProtection\x88\x01\x01\x42\x19\n\x17_termination_protection\"\x14\n\x12UpdateUserResponse\"0\n\x1eGetMachineUserAuthTokenRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"S\n\x1fGetMachineUserAuthTokenResponse\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\x12\x1a\n\x08username\x18\x02 \x01(\tR\x08username\"7\n\x1f\x43reateHumanUserAuthTokenRequest\x12\x14\n\x05\x65mail\x18\x01 \x01(\tR\x05\x65mail\"\x8f\x01\n CreateHumanUserAuthTokenResponse\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\x12\x1a\n\x08username\x18\x02 \x01(\tR\x08username\x12\x39\n\nexpires_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\"4\n\"RefreshMachineUserAuthTokenRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"W\n#RefreshMachineUserAuthTokenResponse\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\x12\x1a\n\x08username\x18\x02 \x01(\tR\x08username\"+\n\x19GetUserExternalIdsRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"^\n\x1aGetUserExternalIdsResponse\x12@\n\x0c\x65xternal_ids\x18\x01 \x03(\x0b\x32\x1d.admin.v1.types.v1.ExternalIdR\x0b\x65xternalIds\"\x8f\x01\n\x1aMapUserToExternalIdRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1f\n\x0b\x65xternal_id\x18\x02 \x01(\tR\nexternalId\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x15\n\x06\x61pp_id\x18\x04 \x01(\tR\x05\x61ppId\"\x1d\n\x1bMapUserToExternalIdResponse\"?\n\x1e\x44\x65leteExternalIdMappingRequest\x12\x1d\n\nmapping_id\x18\x01 \x01(\tR\tmappingId\"!\n\x1f\x44\x65leteExternalIdMappingResponse2\xdd\x08\n\x0bUserService\x12\x44\n\tListUsers\x12\x1a.admin.v1.ListUsersRequest\x1a\x1b.admin.v1.ListUsersResponse\x12G\n\nCreateUser\x12\x1b.admin.v1.CreateUserRequest\x1a\x1c.admin.v1.CreateUserResponse\x12M\n\x0c\x43reateUserV2\x12\x1d.admin.v1.CreateUserV2Request\x1a\x1e.admin.v1.CreateUserV2Response\x12J\n\x0bGetUserById\x12\x1c.admin.v1.GetUserByIdRequest\x1a\x1d.admin.v1.GetUserByIdResponse\x12G\n\nDeleteUser\x12\x1b.admin.v1.DeleteUserRequest\x1a\x1c.admin.v1.DeleteUserResponse\x12G\n\nUpdateUser\x12\x1b.admin.v1.UpdateUserRequest\x1a\x1c.admin.v1.UpdateUserResponse\x12n\n\x17GetMachineUserAuthToken\x12(.admin.v1.GetMachineUserAuthTokenRequest\x1a).admin.v1.GetMachineUserAuthTokenResponse\x12q\n\x18\x43reateHumanUserAuthToken\x12).admin.v1.CreateHumanUserAuthTokenRequest\x1a*.admin.v1.CreateHumanUserAuthTokenResponse\x12z\n\x1bRefreshMachineUserAuthToken\x12,.admin.v1.RefreshMachineUserAuthTokenRequest\x1a-.admin.v1.RefreshMachineUserAuthTokenResponse\x12_\n\x12GetUserExternalIds\x12#.admin.v1.GetUserExternalIdsRequest\x1a$.admin.v1.GetUserExternalIdsResponse\x12\x62\n\x13MapUserToExternalId\x12$.admin.v1.MapUserToExternalIdRequest\x1a%.admin.v1.MapUserToExternalIdResponse\x12n\n\x17\x44\x65leteExternalIdMapping\x12(.admin.v1.DeleteExternalIdMappingRequest\x1a).admin.v1.DeleteExternalIdMappingResponse2\xad\x05\n\x0cGroupService\x12J\n\x0b\x43reateGroup\x12\x1c.admin.v1.CreateGroupRequest\x1a\x1d.admin.v1.CreateGroupResponse\x12G\n\nListGroups\x12\x1b.admin.v1.ListGroupsRequest\x1a\x1c.admin.v1.ListGroupsResponse\x12M\n\x0cGetGroupById\x12\x1d.admin.v1.GetGroupByIdRequest\x1a\x1e.admin.v1.GetGroupByIdResponse\x12J\n\x0bUpdateGroup\x12\x1c.admin.v1.UpdateGroupRequest\x1a\x1d.admin.v1.UpdateGroupResponse\x12Y\n\x10LinkUsersToGroup\x12!.admin.v1.LinkUsersToGroupRequest\x1a\".admin.v1.LinkUsersToGroupResponse\x12_\n\x12LinkUsersToGroupV2\x12#.admin.v1.LinkUsersToGroupV2Request\x1a$.admin.v1.LinkUsersToGroupV2Response\x12\x65\n\x14UnlinkUsersFromGroup\x12%.admin.v1.UnlinkUsersFromGroupRequest\x1a&.admin.v1.UnlinkUsersFromGroupResponse\x12J\n\x0b\x44\x65leteGroup\x12\x1c.admin.v1.DeleteGroupRequest\x1a\x1d.admin.v1.DeleteGroupResponseB\xa5\x01\n\x0c\x63om.admin.v1B\x0fIdentitiesProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.identities_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\017IdentitiesProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_LISTGROUPSREQUEST'].fields_by_name['search_fields']._loaded_options = None
  _globals['_LISTGROUPSREQUEST'].fields_by_name['search_fields']._serialized_options = b'\372B\032\222\001\027\"\025r\023R\004nameR\013description'
  _globals['_LISTUSERSREQUEST'].fields_by_name['search_fields']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['search_fields']._serialized_options = b'\372B\032\222\001\027\"\025r\023R\013db_usernameR\004type'
  _globals['_LISTGROUPSREQUEST']._serialized_start=238
  _globals['_LISTGROUPSREQUEST']._serialized_end=417
  _globals['_CREATEGROUPREQUEST']._serialized_start=420
  _globals['_CREATEGROUPREQUEST']._serialized_end=549
  _globals['_GETGROUPBYIDREQUEST']._serialized_start=551
  _globals['_GETGROUPBYIDREQUEST']._serialized_end=588
  _globals['_DELETEGROUPREQUEST']._serialized_start=590
  _globals['_DELETEGROUPREQUEST']._serialized_end=626
  _globals['_UPDATEGROUPREQUEST']._serialized_start=629
  _globals['_UPDATEGROUPREQUEST']._serialized_end=806
  _globals['_LINKUSERSTOGROUPREQUEST']._serialized_start=808
  _globals['_LINKUSERSTOGROUPREQUEST']._serialized_end=876
  _globals['_LINKUSERSTOGROUPV2REQUEST']._serialized_start=878
  _globals['_LINKUSERSTOGROUPV2REQUEST']._serialized_end=948
  _globals['_UNLINKUSERSFROMGROUPREQUEST']._serialized_start=950
  _globals['_UNLINKUSERSFROMGROUPREQUEST']._serialized_end=1022
  _globals['_CREATEGROUPRESPONSE']._serialized_start=1024
  _globals['_CREATEGROUPRESPONSE']._serialized_end=1093
  _globals['_GETGROUPBYIDRESPONSE']._serialized_start=1095
  _globals['_GETGROUPBYIDRESPONSE']._serialized_end=1165
  _globals['_DELETEGROUPRESPONSE']._serialized_start=1167
  _globals['_DELETEGROUPRESPONSE']._serialized_end=1236
  _globals['_UPDATEGROUPRESPONSE']._serialized_start=1238
  _globals['_UPDATEGROUPRESPONSE']._serialized_end=1307
  _globals['_LISTGROUPSRESPONSE']._serialized_start=1310
  _globals['_LISTGROUPSRESPONSE']._serialized_end=1450
  _globals['_LINKUSERSTOGROUPRESPONSE']._serialized_start=1452
  _globals['_LINKUSERSTOGROUPRESPONSE']._serialized_end=1532
  _globals['_LINKUSERSTOGROUPV2RESPONSE']._serialized_start=1534
  _globals['_LINKUSERSTOGROUPV2RESPONSE']._serialized_end=1616
  _globals['_UNLINKUSERSFROMGROUPRESPONSE']._serialized_start=1618
  _globals['_UNLINKUSERSFROMGROUPRESPONSE']._serialized_end=1702
  _globals['_USERLINKGROUPRESPONSE']._serialized_start=1704
  _globals['_USERLINKGROUPRESPONSE']._serialized_end=1781
  _globals['_LISTUSERSREQUEST']._serialized_start=1784
  _globals['_LISTUSERSREQUEST']._serialized_end=1962
  _globals['_LISTUSERSRESPONSE']._serialized_start=1965
  _globals['_LISTUSERSRESPONSE']._serialized_end=2101
  _globals['_CREATEUSERREQUEST']._serialized_start=2104
  _globals['_CREATEUSERREQUEST']._serialized_end=2471
  _globals['_CREATEUSERRESPONSE']._serialized_start=2473
  _globals['_CREATEUSERRESPONSE']._serialized_end=2567
  _globals['_CREATEUSERV2REQUEST']._serialized_start=2570
  _globals['_CREATEUSERV2REQUEST']._serialized_end=2939
  _globals['_CREATEUSERV2RESPONSE']._serialized_start=2941
  _globals['_CREATEUSERV2RESPONSE']._serialized_end=2979
  _globals['_GETUSERBYIDREQUEST']._serialized_start=2981
  _globals['_GETUSERBYIDREQUEST']._serialized_end=3017
  _globals['_GETUSERBYIDRESPONSE']._serialized_start=3019
  _globals['_GETUSERBYIDRESPONSE']._serialized_end=3085
  _globals['_DELETEUSERREQUEST']._serialized_start=3087
  _globals['_DELETEUSERREQUEST']._serialized_end=3122
  _globals['_DELETEUSERRESPONSE']._serialized_start=3124
  _globals['_DELETEUSERRESPONSE']._serialized_end=3144
  _globals['_UPDATEUSERREQUEST']._serialized_start=3147
  _globals['_UPDATEUSERREQUEST']._serialized_end=3371
  _globals['_UPDATEUSERRESPONSE']._serialized_start=3373
  _globals['_UPDATEUSERRESPONSE']._serialized_end=3393
  _globals['_GETMACHINEUSERAUTHTOKENREQUEST']._serialized_start=3395
  _globals['_GETMACHINEUSERAUTHTOKENREQUEST']._serialized_end=3443
  _globals['_GETMACHINEUSERAUTHTOKENRESPONSE']._serialized_start=3445
  _globals['_GETMACHINEUSERAUTHTOKENRESPONSE']._serialized_end=3528
  _globals['_CREATEHUMANUSERAUTHTOKENREQUEST']._serialized_start=3530
  _globals['_CREATEHUMANUSERAUTHTOKENREQUEST']._serialized_end=3585
  _globals['_CREATEHUMANUSERAUTHTOKENRESPONSE']._serialized_start=3588
  _globals['_CREATEHUMANUSERAUTHTOKENRESPONSE']._serialized_end=3731
  _globals['_REFRESHMACHINEUSERAUTHTOKENREQUEST']._serialized_start=3733
  _globals['_REFRESHMACHINEUSERAUTHTOKENREQUEST']._serialized_end=3785
  _globals['_REFRESHMACHINEUSERAUTHTOKENRESPONSE']._serialized_start=3787
  _globals['_REFRESHMACHINEUSERAUTHTOKENRESPONSE']._serialized_end=3874
  _globals['_GETUSEREXTERNALIDSREQUEST']._serialized_start=3876
  _globals['_GETUSEREXTERNALIDSREQUEST']._serialized_end=3919
  _globals['_GETUSEREXTERNALIDSRESPONSE']._serialized_start=3921
  _globals['_GETUSEREXTERNALIDSRESPONSE']._serialized_end=4015
  _globals['_MAPUSERTOEXTERNALIDREQUEST']._serialized_start=4018
  _globals['_MAPUSERTOEXTERNALIDREQUEST']._serialized_end=4161
  _globals['_MAPUSERTOEXTERNALIDRESPONSE']._serialized_start=4163
  _globals['_MAPUSERTOEXTERNALIDRESPONSE']._serialized_end=4192
  _globals['_DELETEEXTERNALIDMAPPINGREQUEST']._serialized_start=4194
  _globals['_DELETEEXTERNALIDMAPPINGREQUEST']._serialized_end=4257
  _globals['_DELETEEXTERNALIDMAPPINGRESPONSE']._serialized_start=4259
  _globals['_DELETEEXTERNALIDMAPPINGRESPONSE']._serialized_end=4292
  _globals['_USERSERVICE']._serialized_start=4295
  _globals['_USERSERVICE']._serialized_end=5412
  _globals['_GROUPSERVICE']._serialized_start=5415
  _globals['_GROUPSERVICE']._serialized_end=6100
# @@protoc_insertion_point(module_scope)



import grpc


from .gen.admin.v1.integration_mfa_pb2 import (
	ListIntegrationMfasRequest,
	ListIntegrationMfasResponse,
	GetIntegrationMfaByIdRequest,
	GetIntegrationMfaByIdResponse,
	CreateIntegrationMfaRequest,
	CreateIntegrationMfaResponse,
	DeleteIntegrationMfaRequest,
	DeleteIntegrationMfaResponse,
	UpdateIntegrationMfaRequest,
	UpdateIntegrationMfaResponse,
	IntegrationMfa,
)

from .gen.admin.v1.integration_mfa_pb2_grpc import IntegrationMfaServiceStub
class IntegrationMfaService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = IntegrationMfaServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def ListIntegrationMfas(self, request: ListIntegrationMfasRequest) -> ListIntegrationMfasResponse:
		return self.stub.ListIntegrationMfas(request, metadata=self.headers)

	def GetIntegrationMfaById(self, request: GetIntegrationMfaByIdRequest) -> GetIntegrationMfaByIdResponse:
		return self.stub.GetIntegrationMfaById(request, metadata=self.headers)

	def UpdateIntegrationMfa(self, request: UpdateIntegrationMfaRequest) -> UpdateIntegrationMfaResponse:
		return self.stub.UpdateIntegrationMfa(request, metadata=self.headers)

	def CreateIntegrationMfa(self, request: CreateIntegrationMfaRequest) -> CreateIntegrationMfaResponse:
		return self.stub.CreateIntegrationMfa(request, metadata=self.headers)

	def DeleteIntegrationMfa(self, request: DeleteIntegrationMfaRequest) -> DeleteIntegrationMfaResponse:
		return self.stub.DeleteIntegrationMfa(request, metadata=self.headers)




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/integration_incident.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import incident_account_pb2 as admin_dot_v1_dot_types_dot_v1_dot_incident__account__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#admin/v1/integration_incident.proto\x12\x08\x61\x64min.v1\x1a(admin/v1/types/v1/incident_account.proto\"A\n DeleteIncidentAccountByIdRequest\x12\x1d\n\naccount_id\x18\x01 \x01(\tR\taccountId\"#\n!DeleteIncidentAccountByIdResponse\"t\n\x1d\x43onnectIncidentAccountRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x12\n\x04logo\x18\x03 \x01(\tR\x04logo\x12\x17\n\x07\x61pi_key\x18\x04 \x01(\tR\x06\x61piKey\"0\n\x1e\x43onnectIncidentAccountResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"c\n\x1aGetIncidentAccountsRequest\x12\x14\n\x05limit\x18\x01 \x01(\tR\x05limit\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\x12\x17\n\x07go_back\x18\x03 \x01(\x08R\x06goBack\"\xa6\x01\n\x1bGetIncidentAccountsResponse\x12>\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\".admin.v1.types.v1.IncidentAccountR\x08\x61\x63\x63ounts\x12,\n\x12last_evaluated_key\x18\x02 \x01(\tR\x10lastEvaluatedKey\x12\x19\n\x08has_more\x18\x03 \x01(\x08R\x07hasMore\"/\n\x1dGetIncidentAccountByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"^\n\x1eGetIncidentAccountByIdResponse\x12<\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\".admin.v1.types.v1.IncidentAccountR\x07\x61\x63\x63ount2\xc5\x03\n\x0fIncidentService\x12k\n\x16\x43onnectIncidentAccount\x12\'.admin.v1.ConnectIncidentAccountRequest\x1a(.admin.v1.ConnectIncidentAccountResponse\x12\x62\n\x13GetIncidentAccounts\x12$.admin.v1.GetIncidentAccountsRequest\x1a%.admin.v1.GetIncidentAccountsResponse\x12k\n\x16GetIncidentAccountById\x12\'.admin.v1.GetIncidentAccountByIdRequest\x1a(.admin.v1.GetIncidentAccountByIdResponse\x12t\n\x19\x44\x65leteIncidentAccountById\x12*.admin.v1.DeleteIncidentAccountByIdRequest\x1a+.admin.v1.DeleteIncidentAccountByIdResponseB\xb3\x01\n\x0c\x63om.admin.v1B\x18IntegrationIncidentProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_incident_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\014com.admin.v1B\030IntegrationIncidentProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_DELETEINCIDENTACCOUNTBYIDREQUEST']._serialized_start=91
  _globals['_DELETEINCIDENTACCOUNTBYIDREQUEST']._serialized_end=156
  _globals['_DELETEINCIDENTACCOUNTBYIDRESPONSE']._serialized_start=158
  _globals['_DELETEINCIDENTACCOUNTBYIDRESPONSE']._serialized_end=193
  _globals['_CONNECTINCIDENTACCOUNTREQUEST']._serialized_start=195
  _globals['_CONNECTINCIDENTACCOUNTREQUEST']._serialized_end=311
  _globals['_CONNECTINCIDENTACCOUNTRESPONSE']._serialized_start=313
  _globals['_CONNECTINCIDENTACCOUNTRESPONSE']._serialized_end=361
  _globals['_GETINCIDENTACCOUNTSREQUEST']._serialized_start=363
  _globals['_GETINCIDENTACCOUNTSREQUEST']._serialized_end=462
  _globals['_GETINCIDENTACCOUNTSRESPONSE']._serialized_start=465
  _globals['_GETINCIDENTACCOUNTSRESPONSE']._serialized_end=631
  _globals['_GETINCIDENTACCOUNTBYIDREQUEST']._serialized_start=633
  _globals['_GETINCIDENTACCOUNTBYIDREQUEST']._serialized_end=680
  _globals['_GETINCIDENTACCOUNTBYIDRESPONSE']._serialized_start=682
  _globals['_GETINCIDENTACCOUNTBYIDRESPONSE']._serialized_end=776
  _globals['_INCIDENTSERVICE']._serialized_start=779
  _globals['_INCIDENTSERVICE']._serialized_end=1232
# @@protoc_insertion_point(module_scope)



from .types.v1 import list_metadata_pb2 as _list_metadata_pb2
from .types.v1 import sidecar_pb2 as _sidecar_pb2
from .types.v1 import sidecar_link_pb2 as _sidecar_link_pb2
from ...validate.v1 import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListSidecarsRequest(_message.Message):
    __slots__ = ("limit", "cursor", "order", "search", "search_fields")
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    CURSOR_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELDS_FIELD_NUMBER: _ClassVar[int]
    limit: int
    cursor: str
    order: str
    search: str
    search_fields: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, limit: _Optional[int] = ..., cursor: _Optional[str] = ..., order: _Optional[str] = ..., search: _Optional[str] = ..., search_fields: _Optional[_Iterable[str]] = ...) -> None: ...

class ListSidecarsResponse(_message.Message):
    __slots__ = ("sidecars", "list_metadata")
    SIDECARS_FIELD_NUMBER: _ClassVar[int]
    LIST_METADATA_FIELD_NUMBER: _ClassVar[int]
    sidecars: _containers.RepeatedCompositeFieldContainer[_sidecar_pb2.Sidecar]
    list_metadata: _list_metadata_pb2.ListMetadata
    def __init__(self, sidecars: _Optional[_Iterable[_Union[_sidecar_pb2.Sidecar, _Mapping]]] = ..., list_metadata: _Optional[_Union[_list_metadata_pb2.ListMetadata, _Mapping]] = ...) -> None: ...

class GetSidecarVersionsRequest(_message.Message):
    __slots__ = ("technology",)
    TECHNOLOGY_FIELD_NUMBER: _ClassVar[int]
    technology: str
    def __init__(self, technology: _Optional[str] = ...) -> None: ...

class GetSidecarVersionsResponse(_message.Message):
    __slots__ = ("versions",)
    VERSIONS_FIELD_NUMBER: _ClassVar[int]
    versions: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, versions: _Optional[_Iterable[str]] = ...) -> None: ...

class CreateSidecarRequest(_message.Message):
    __slots__ = ("name", "technology", "deployment_type", "dataplane_id", "datastore_id", "fail_open", "global_kms_decrypt", "formal_hostname", "version", "network_type", "termination_protection")
    NAME_FIELD_NUMBER: _ClassVar[int]
    TECHNOLOGY_FIELD_NUMBER: _ClassVar[int]
    DEPLOYMENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    DATAPLANE_ID_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    FAIL_OPEN_FIELD_NUMBER: _ClassVar[int]
    GLOBAL_KMS_DECRYPT_FIELD_NUMBER: _ClassVar[int]
    FORMAL_HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    NETWORK_TYPE_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    name: str
    technology: str
    deployment_type: str
    dataplane_id: str
    datastore_id: str
    fail_open: bool
    global_kms_decrypt: bool
    formal_hostname: str
    version: str
    network_type: str
    termination_protection: bool
    def __init__(self, name: _Optional[str] = ..., technology: _Optional[str] = ..., deployment_type: _Optional[str] = ..., dataplane_id: _Optional[str] = ..., datastore_id: _Optional[str] = ..., fail_open: bool = ..., global_kms_decrypt: bool = ..., formal_hostname: _Optional[str] = ..., version: _Optional[str] = ..., network_type: _Optional[str] = ..., termination_protection: bool = ...) -> None: ...

class CreateSidecarResponse(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetSidecarByIdRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetSidecarByIdResponse(_message.Message):
    __slots__ = ("sidecar",)
    SIDECAR_FIELD_NUMBER: _ClassVar[int]
    sidecar: _sidecar_pb2.Sidecar
    def __init__(self, sidecar: _Optional[_Union[_sidecar_pb2.Sidecar, _Mapping]] = ...) -> None: ...

class GetSidecarTlsCertificateByIdRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetSidecarTlsCertificateByIdResponse(_message.Message):
    __slots__ = ("secret",)
    SECRET_FIELD_NUMBER: _ClassVar[int]
    secret: str
    def __init__(self, secret: _Optional[str] = ...) -> None: ...

class UpdateSidecarNameRequest(_message.Message):
    __slots__ = ("id", "name")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class UpdateSidecarNameResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UpdateSidecarVersionRequest(_message.Message):
    __slots__ = ("id", "version")
    ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    id: str
    version: str
    def __init__(self, id: _Optional[str] = ..., version: _Optional[str] = ...) -> None: ...

class UpdateSidecarVersionResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UpdateSidecarFormalHostnameRequest(_message.Message):
    __slots__ = ("id", "hostname")
    ID_FIELD_NUMBER: _ClassVar[int]
    HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    id: str
    hostname: str
    def __init__(self, id: _Optional[str] = ..., hostname: _Optional[str] = ...) -> None: ...

class UpdateSidecarFormalHostnameResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UpdateSidecarKmsDecryptPolicyRequest(_message.Message):
    __slots__ = ("id", "enabled")
    ID_FIELD_NUMBER: _ClassVar[int]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    id: str
    enabled: bool
    def __init__(self, id: _Optional[str] = ..., enabled: bool = ...) -> None: ...

class UpdateSidecarKmsDecryptPolicyResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteSidecarRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteSidecarResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class CreateSidecarDatastoreLinkRequest(_message.Message):
    __slots__ = ("datastore_id", "sidecar_id", "port", "termination_protection")
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    SIDECAR_ID_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    datastore_id: str
    sidecar_id: str
    port: int
    termination_protection: bool
    def __init__(self, datastore_id: _Optional[str] = ..., sidecar_id: _Optional[str] = ..., port: _Optional[int] = ..., termination_protection: bool = ...) -> None: ...

class CreateSidecarDatastoreLinkResponse(_message.Message):
    __slots__ = ("link_id",)
    LINK_ID_FIELD_NUMBER: _ClassVar[int]
    link_id: str
    def __init__(self, link_id: _Optional[str] = ...) -> None: ...

class DeleteSidecarDatastoreLinkRequest(_message.Message):
    __slots__ = ("link_id",)
    LINK_ID_FIELD_NUMBER: _ClassVar[int]
    link_id: str
    def __init__(self, link_id: _Optional[str] = ...) -> None: ...

class DeleteSidecarDatastoreLinkResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetLinkByIdRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetLinkByIdResponse(_message.Message):
    __slots__ = ("link",)
    LINK_FIELD_NUMBER: _ClassVar[int]
    link: _sidecar_link_pb2.SidecarLink
    def __init__(self, link: _Optional[_Union[_sidecar_link_pb2.SidecarLink, _Mapping]] = ...) -> None: ...

class GetLinksBySidecarIdRequest(_message.Message):
    __slots__ = ("sidecar_id",)
    SIDECAR_ID_FIELD_NUMBER: _ClassVar[int]
    sidecar_id: str
    def __init__(self, sidecar_id: _Optional[str] = ...) -> None: ...

class GetLinksBySidecarIdResponse(_message.Message):
    __slots__ = ("links",)
    LINKS_FIELD_NUMBER: _ClassVar[int]
    links: _containers.RepeatedCompositeFieldContainer[_sidecar_link_pb2.SidecarLink]
    def __init__(self, links: _Optional[_Iterable[_Union[_sidecar_link_pb2.SidecarLink, _Mapping]]] = ...) -> None: ...

class GetLinksByDatastoreIdRequest(_message.Message):
    __slots__ = ("datastore_id",)
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    datastore_id: str
    def __init__(self, datastore_id: _Optional[str] = ...) -> None: ...

class GetLinksByDatastoreIdResponse(_message.Message):
    __slots__ = ("links",)
    LINKS_FIELD_NUMBER: _ClassVar[int]
    links: _containers.RepeatedCompositeFieldContainer[_sidecar_link_pb2.SidecarLink]
    def __init__(self, links: _Optional[_Iterable[_Union[_sidecar_link_pb2.SidecarLink, _Mapping]]] = ...) -> None: ...

class UpdateTerminationProtectionRequest(_message.Message):
    __slots__ = ("id", "enabled")
    ID_FIELD_NUMBER: _ClassVar[int]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    id: str
    enabled: bool
    def __init__(self, id: _Optional[str] = ..., enabled: bool = ...) -> None: ...

class UpdateTerminationProtectionResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UpdateSidecarDatastoreLinkRequest(_message.Message):
    __slots__ = ("id", "termination_protection")
    ID_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    id: str
    termination_protection: bool
    def __init__(self, id: _Optional[str] = ..., termination_protection: bool = ...) -> None: ...

class UpdateSidecarDatastoreLinkResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...
